]> cloudbase.mooo.com Git - z180-stamp.git/blobdiff - avr/cli.c
Store only command line input in history buffer, but not data (i.e mm command)
[z180-stamp.git] / avr / cli.c
index e66554ac0ed58240966d70d8ba9c1c5e09660733..aa2c38883b1f58fe230166aa11bc9e814b73c080 100644 (file)
--- a/avr/cli.c
+++ b/avr/cli.c
@@ -8,9 +8,10 @@
  * (C) Copyright 2005
  * JinHua Luo, GuangDong Linux Center, <luo.jinhua@gd-linux.com>
  *
- * SPDX-License-Identifier:    GPL-2.0+
+ * SPDX-License-Identifier:    GPL-2.0
  */
 
+#include "cli.h"
 #include "common.h"
 
 #include <string.h>
@@ -25,7 +26,6 @@
 #include "env.h"
 #include "cli_readline.h"
 #include "con-utils.h"
-#include "cli.h"
 
 
 /* FIXME: Quoting problems */
@@ -177,7 +177,7 @@ char *process_macros(char *input, char *output)
                                if (c == '}') {
                                        /* Terminate variable name */
                                        *(inp-1) = '\0';
-                                       const char *envval = getenv(varname);
+                                       const char *envval = getenv_char(varname);
                                        *(inp-1) = '}';
                                        /* Copy into the line if it exists */
                                        if (envval != NULL)
@@ -210,7 +210,7 @@ char *process_macros(char *input, char *output)
  * WARNING:
  *
  * We must create a temporary copy of the command since the command we get
* may be the result from getenv(), which returns a pointer directly to
  * the environment data, which may change magicly when the command we run
  * creates or modifies environment variables (like "bootp" does).
  *
@@ -364,7 +364,7 @@ void cli_loop(void)
        int rc = 1;
 
        for (;;) {
-               len = cli_readline(PSTR(CONFIG_SYS_PROMPT));
+               len = cli_readline(PSTR(CONFIG_SYS_PROMPT), 1);
 
                flag = 0;       /* assume no special flags for now */
                if (len > 0) {
@@ -398,7 +398,7 @@ command_ret_t do_run(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
        for (i = 1; i < argc; ++i) {
                char *arg;
 
-               arg = getenv(argv[i]);
+               arg = getenv_char(argv[i]);
                if (arg == NULL) {
                        printf_P(PSTR("## Error: \"%s\" is not set\n"), argv[i]);
                        return CMD_RET_FAILURE;
@@ -210,7 +210,7 @@ char *process_macros(char *input, char *output)
  *
  * We must create a temporary copy of the command since the command we get
- * may be the result from getenv(), which returns a pointer directly to
+ * may be the result from getenv_char(), which returns a pointer directly to
  * the environment data, which may change magicly when the command we run
  * creates or modifies environment variables (like "bootp" does).